@@ -51,12 +51,24 @@ class CreateAppTester(unittest.TestCase):
         self.assertTrue(os.path.exists(os.path.join(outdir, "tests", "test_cli.py")))
         self.assertTrue(os.path.exists(os.path.join(outdir, "tox.ini")))
         os.chdir(outdir)
-        subprocess.check_call("pip install -e .", shell=True)
-        subprocess.check_call("pip install -r requirements.testing.txt", shell=True)
-        subprocess.check_call("python tests/test_cli.py", shell=True)
-        subprocess.check_call("pylint src tests", shell=True)
-        subprocess.check_call("flake8 src tests", shell=True)
-        subprocess.check_call("mypy src tests", shell=True)
+
+        cmds = [
+            "pip install -e .",
+            "pip install -r requirements.testing.txt",
+            "black src",
+            "black tests",
+            "python tests/test_cli.py",
+            "pylint src tests",
+            "flake8 src tests",
+            "mypy src tests",
+        ]
+        assert os.path.exists(os.path.join(outdir, "lint"))
+        env_with_current_dir = os.environ.copy()
+        os_sep = ";" if os.name == "nt" else ":"
+        env_with_current_dir["PATH"] = f"{outdir}{os_sep}{env_with_current_dir['PATH']}"
+        for cmd in cmds:
+            rtn = subprocess.call(cmd, env=env_with_current_dir, shell=True)
+            self.assertEqual(0, rtn, f"Command failed: {cmd}")
 
 
 if __name__ == "__main__":
